@@ -45,6 +45,7 @@ sub spawn {
             # public events
             attack_move      => \&_onpub_attack_move,
             ask_move_armies  => \&_onpub_ask_move_armies,
+            shutdown         => \&_onpub_shutdown,
         },
     );
     return $session->ID;
@@ -139,6 +140,17 @@ sub _onpub_ask_move_armies {
 }
 
 
+#
+# event: shutdown()
+#
+# kill current session. the toplevel window has already been destroyed.
+#
+sub _onpub_shutdown {
+    my $h = $_[HEAP];
+    K->alias_remove('move-armies');
+}
+
+
 # -- private events
 
 #
